Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(703)

Unified Diff: chrome/browser/dom_ui/new_tab_ui_uitest.cc

Issue 449073: Put "make this my home page" link into the tip section.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/dom_ui/ntp_resource_cache.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/dom_ui/new_tab_ui_uitest.cc
===================================================================
--- chrome/browser/dom_ui/new_tab_ui_uitest.cc (revision 33574)
+++ chrome/browser/dom_ui/new_tab_ui_uitest.cc (working copy)
@@ -130,16 +130,19 @@
// TODO(arv): Extract common patterns for doing js testing.
- // Fire click
+ // Fire click. Because tip service is turned off for testing, we first
+ // force the "make this my home page" tip to appear.
// TODO(arv): Find screen position of element and use a lower level click
// emulation.
bool result;
ASSERT_TRUE(tab->ExecuteAndExtractBool(L"",
L"window.domAutomationController.send("
L"(function() {"
+ L" tipCache = [{\"set_homepage_tip\":\"Make this the home page\"}];"
+ L" renderTip();"
L" var e = document.createEvent('Event');"
L" e.initEvent('click', true, true);"
- L" var el = document.querySelector('#set-as-home-page > *');"
+ L" var el = document.querySelector('#tip-line > button');"
L" el.dispatchEvent(e);"
L" return true;"
L"})()"
@@ -147,17 +150,17 @@
&result));
ASSERT_TRUE(result);
- // Make sure set as home page element is hidden.
- std::wstring style_display;
+ // Make sure text of "set as home page" tip has been removed.
+ std::wstring tip_text_content;
ASSERT_TRUE(tab->ExecuteAndExtractString(L"",
L"window.domAutomationController.send("
L"(function() {"
- L" var el = document.querySelector('#set-as-home-page');"
- L" return el.style.display;"
+ L" var el = document.querySelector('#tip-line');"
+ L" return el.textContent;"
L"})()"
L")",
- &style_display));
- ASSERT_EQ(L"none", style_display);
+ &tip_text_content));
+ ASSERT_EQ(L"", tip_text_content);
// Make sure that the notification is visible
bool has_class;
« no previous file with comments | « no previous file | chrome/browser/dom_ui/ntp_resource_cache.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698